function Ytest = gmdhpredict(model, Xtest)







% Predicts output values for the given query points Xq using a GMDH model
%
% Call
%   [Ytest] = gmdhpredict(model, Xtest)
%
% Input
% model     : GMDH model
% Xq        : Inputs of query data points (Xtest(i,:)), i = 1,...,ntst
%
% Output
% Yq        : Predicted outputs of query data points (Ytest(i)), i = 1,...,ntst











if nargin < 2
    error('Too few input arguments.');
end
if model.d ~= size(Xtest, 2)
    error('The matrix should have the same number of columns as the matrix with which the network was built.');
end

[n, d] = size(Xtest);
Ytest = zeros(n, 1);

for q = 1 : n
    for i = 1 : model.numLayers
        if i ~= model.numLayers
            Xq_tmp = zeros(1, model.layer(i).numNeurons);
        end
        for j = 1 : model.layer(i).numNeurons

            %create matrix for all polynomial terms
            numTerms =  size(model.layer(i).terms(j).r,1);
            Vals = ones(numTerms,1);
            for idx = 2 : numTerms
                bf = model.layer(i).terms(j).r(idx, :);
                t = bf > 0;
                tmp = Xtest(q, model.layer(i).inputs(j,t)) .^ bf(1, t);
                if size(tmp, 2) == 1
                    Vals(idx,1) = tmp;
                else
                    Vals(idx,1) = prod(tmp, 2);
                end
            end

            %predict output value
            predY = model.layer(i).coefs(j,1:numTerms) * Vals;
            if i ~= model.numLayers
                %Xq(q, d+j) = predY;
                Xq_tmp(j) = predY;
            else
                Ytest(q) = predY;
            end

        end
        if i ~= model.numLayers
            Xtest(q, d+1:d+model.layer(i).numNeurons) = Xq_tmp;
        end
    end
end

return
